# This class sets up console.conf for the master. Which essentially defines
# where the master should look to find the console, which certificate it should
# use, and how to send reports to the console.
#
# This class is called internally by the Master profile, and should not be called
# directly.
#
# @param console_host [String] The hostname of the console.
# @console_server_certname [String] The name on the certificate used by the console.
# @dashboard_port [Integer] The port that the dashboard service listens on.
class puppet_enterprise::profile::master::console(
  $console_host,
  $console_server_certname,
  $dashboard_port,
) inherits puppet_enterprise::params {

  $confdir = '/etc/puppetlabs/puppet'

  Pe_ini_setting {
    ensure  => present,
    section => 'main'
  }

  # Start
  # console.conf
  file { "${confdir}/console.conf":
    mode    => '0644',
  }

  pe_ini_setting { 'console.conf_server':
    path    => "${confdir}/console.conf",
    setting => 'server',
    value   => $console_host,
  }

  pe_ini_setting { 'console.conf_port':
    path    => "${confdir}/console.conf",
    setting => 'port',
    value   => $dashboard_port,
  }

  pe_ini_setting { 'console.conf_certificate_name':
    path    => "${confdir}/console.conf",
    setting => 'certificate_name',
    value   => $console_server_certname,
  }
  # End

  # Start
  # puppet.conf
  pe_ini_subsetting { 'reports_console' :
    ensure               => present,
    path                 => "${confdir}/puppet.conf",
    section              => 'master',
    setting              => 'reports',
    subsetting           => 'console',
    subsetting_separator => ',',
  }

  # End

}
